@@ -106,6 +106,7 @@ class Param(CompleterParam):
         self.argname_shorten: bool = argname_shorten
         self.hit: bool = False
         self.is_help: bool = False
+        self.is_full: bool = False
         self.ns_param: "ParamNamespace" = None
         self._desc: List[str] = desc or ["No description."]
         self._stack: List[Any] = []
@@ -511,7 +512,7 @@ class Param(CompleterParam):
 
         try:
             val = self.callback(self.value, all_values)
-        except TypeError as terr:
+        except TypeError as terr:  # pragma: no cover
             # len() takes exactly one argument (2 given)
             # <lambda>() takes 1 positional argument but 2 were given
             if not re.search(r"takes .+ argument .+ given", str(terr)):
@@ -565,7 +566,7 @@ class ParamFloat(Param):
         val = super()._value()
         try:
             return None if val is None else float(val)
-        except ValueError as verr:
+        except ValueError as verr:  # pragma: no cover
             raise PyParamValueError(str(verr)) from None
 
 
@@ -844,7 +845,7 @@ class ParamJson(Param):
     def _value(self) -> Any:
         val: Any = super()._value()
 
-        if val is None:
+        if val is None:  # pragma: no cover
             return None
 
         if isinstance(val, str):
@@ -1133,7 +1134,7 @@ class ParamNamespace(Param):
 
         try:
             val = self.callback(ns_callback_applied, all_values)
-        except TypeError as terr:
+        except TypeError as terr:  # pragma: no cover
             # len() takes exactly one argument (2 given)
             # <lambda>() takes 1 positional argument but 2 were given
             if not re.search(r"takes .+ argument .+ given", str(terr)):
