@@ -14,7 +14,7 @@ from .defaults import PARAMS as PARAMS_DEFAULT
 from .defaults import POSITIONAL
 from .exceptions import PyParamNameError, PyParamTypeError, PyParamValueError
 from .help import HelpAssembler, ProgHighlighter
-from .param import PARAM_MAPPINGS
+from .param import PARAM_MAPPINGS, ParamJson
 from .utils import (
     Namespace,
     always_list,
@@ -85,6 +85,7 @@ class Params(Completer):
         help_on_void: Union[str, bool] = None,
         help_callback: Callable = None,
         help_modifier: Callable = None,
+        fullopt_keys: Union[str, List[str]] = None,
         prefix: str = "auto",
         arbitrary: Union[str, bool] = False,
         theme: Union[str, "Theme"] = "default",
@@ -102,6 +103,11 @@ class Params(Completer):
             if help_keys is None
             else always_list(help_keys)
         )
+        self.fullopt_keys: List[str] = (
+            PARAMS_DEFAULT.fullopt_keys
+            if fullopt_keys is None
+            else always_list(fullopt_keys)
+        )
         self.help_cmds: List[str] = (
             PARAMS_DEFAULT.help_cmds
             if help_cmds is None
@@ -130,6 +136,8 @@ class Params(Completer):
         self.help_modifier = help_modifier
 
         self.assembler = HelpAssembler(self.prog, theme, help_callback)
+
+        self.has_hidden = False
         super().__init__()
 
     @property
@@ -161,6 +169,8 @@ class Params(Completer):
         Returns:
             The shortest/longest name of the parameter
         """
+        if not self.names:
+            return None
         return list(sorted(self.names, key=len))[0 if "short" in which else -1]
 
     def namestr(self, sep: str = ", ") -> str:
@@ -296,6 +306,9 @@ class Params(Completer):
                 if type is None
                 else type
             )
+            show = PARAM_DEFAULT.show if show is None else show
+            if not show:
+                self.has_hidden = True
 
             param = PARAM_MAPPINGS[maintype](  # type: ignore
                 names=names,
@@ -304,7 +317,7 @@ class Params(Completer):
                 if desc is None
                 else always_list(desc, strip=False, split=False),
                 prefix=self.prefix,
-                show=PARAM_DEFAULT.show if show is None else show,
+                show=show,
                 required=(
                     PARAM_DEFAULT.required if required is None else required
                 ),
@@ -328,6 +341,8 @@ class Params(Completer):
 
         if any(name in self.help_keys for name in param.names):
             param.is_help = True
+        if any(name in self.fullopt_keys for name in param.names):
+            param.is_help = param.is_full = True
 
         if param.namespaces(0):
             # add namespace parameter automatically
@@ -449,13 +464,13 @@ class Params(Completer):
             groups.append(command)
         return command
 
-    def print_help(self, exit_code: int = 1) -> None:
+    def print_help(self, exit_code: int = 1, full: bool = False) -> None:
         """Print the help information and exit
 
         Args:
             exit_code: The exit code or False to not exit
         """
-        self.assembler.assemble(self)
+        self.assembler.assemble(self, full=full)
         self.assembler.printout()
         if exit_code is not False:
             sys.exit(exit_code)
@@ -483,7 +498,7 @@ class Params(Completer):
                 if not ignore_errors:
                     logger.error("%r: %s", param.namestr(), pve)
                     self.print_help()
-            except Exception:
+            except Exception:  # pragma: no cover
                 if not ignore_errors:
                     raise
             else:
@@ -499,7 +514,7 @@ class Params(Completer):
             try:
                 value: Any = param.apply_callback(ns_no_callback)
             except (PyParamTypeError, PyParamValueError) as pte:
-                if not ignore_errors:
+                if not ignore_errors:  # pragma: no cover
                     logger.error("%r: %s", param.namestr(), pte)
                     self.print_help()
             except Exception:
@@ -532,6 +547,13 @@ class Params(Completer):
             desc="Print help information for this command",
             force=True,
         )
+        if self.has_hidden:
+            self.add_param(
+                self.fullopt_keys,
+                type="bool",
+                desc="Show full options for this command",
+                force=True,
+            )
 
         help_cmd: "Params" = None
         if self.commands:
@@ -581,9 +603,9 @@ class Params(Completer):
             and len(self.commands) > 1  # together with help command
         ):
             command_passed = namespace[namespace.__command__][POSITIONAL]
-            if not command_passed:
+            if not command_passed:  # pragma: no cover
                 self.print_help()
-            elif command_passed not in self.commands:
+            elif command_passed not in self.commands:  # pragma: no cover
                 logger.error("Unknown command: %r", command_passed)
                 self.print_help()
             else:
@@ -631,8 +653,15 @@ class Params(Completer):
                 param_value,
             )
             # as long as the help argument hit
-            if param_name in self.help_keys or (param and param.is_help):
-                self.print_help()
+            if (
+                param_name in self.help_keys
+                or param_name in self.fullopt_keys
+                or (param and param.is_help)
+            ):
+                self.print_help(
+                    full=param_name in self.fullopt_keys
+                    or (param and param.is_full)
+                )
 
             if param:
                 if prev_param:
@@ -1106,6 +1135,27 @@ class Params(Completer):
             # scan for the attributes
             for key, val in dict_obj.items():
                 if key in all_params:
+                    # if val is a dict
+                    if isinstance(val, dict):
+                        # see if key has already defined and is a json parameter
+                        param = self.get_param(key)
+                        if isinstance(param, ParamJson) and (
+                            "default" not in val
+                            or set(val)
+                            - {
+                                "default",
+                                "type",
+                                "desc",
+                                "required",
+                                "group",
+                                "type_frozen",
+                                "argname_shorten",
+                                "choices",
+                            }
+                        ):
+                            all_params[key]["default"] = val
+                            continue
+
                     # if it is a dict, and there is not other attributes
                     # assigned like "arg.desc", that means this dictionary
                     # contains all attributes
@@ -1115,6 +1165,7 @@ class Params(Completer):
                         all_params[key] = val
                     else:
                         all_params[key]["default"] = val
+
                 elif "." in key:
                     # Type: str, str
                     param_name, param_attr = key.split(".", 1)
